<?php
/**
* Header Options.
*
* @package Coverage
*/

$coverage_default = coverage_get_default_theme_options();
$coverage_page_lists = coverage_page_lists();
$coverage_post_category_list = coverage_post_category_list();

// Header Advertise Area Section.
$wp_customize->add_section( 'main_header_setting',
	array(
	'title'      => esc_html__( 'Header Settings', 'coverage' ),
	'priority'   => 10,
	'capability' => 'edit_theme_options',
    'panel'      => 'theme_option_panel',
	)
);

// Enable Disable Search.
$wp_customize->add_setting('ed_header_search',
    array(
        'default' => $coverage_default['ed_header_search'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_header_search',
    array(
        'label' => esc_html__('Enable Search', 'coverage'),
        'section' => 'main_header_setting',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('ed_header_ad',
    array(
        'default' => $coverage_default['ed_header_ad'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_header_ad',
    array(
        'label' => esc_html__('Enable Top Advertisement Area', 'coverage'),
        'section' => 'main_header_setting',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('header_ad_image',
    array(
        'default' => '',
        'sanitize_callback' => 'esc_url_raw'
    )
);
$wp_customize->add_control( new WP_Customize_Image_Control(
    $wp_customize,
    'header_ad_image',
        array(
            'label'      => esc_html__( 'Top Header AD Image', 'coverage' ),
            'section'    => 'main_header_setting',
            'active_callback' => 'coverage_header_ad_ac',
        )
    )
);

$wp_customize->add_setting('ed_header_link',
    array(
        'default' => '',
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'esc_url_raw',
    )
);
$wp_customize->add_control('ed_header_link',
    array(
        'label' => esc_html__('AD Image Link', 'coverage'),
        'section' => 'main_header_setting',
        'type' => 'text',
        'active_callback' => 'coverage_header_ad_ac',
    )
);

// Archive Layout.
$wp_customize->add_setting(
    'coverage_header_bg_size',
    array(
        'default'           => $coverage_default['coverage_header_bg_size'],
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'absint'
    )
);
$wp_customize->add_control('coverage_header_bg_size',
        array(
            'type'       => 'select',
            'section'       => 'header_image',
            'label'         => esc_html__( 'Header BG Size', 'coverage' ),
            'choices'       => array(
                '1'  => esc_html__( 'Small', 'coverage' ),
                '2'  => esc_html__( 'Medium', 'coverage' ),
                '3'  => esc_html__( 'Large', 'coverage' ),
            )
        )
);

$wp_customize->add_setting('ed_header_bg_fixed',
    array(
        'default' => $coverage_default['ed_header_bg_fixed'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_header_bg_fixed',
    array(
        'label' => esc_html__('Enable Fixed BG', 'coverage'),
        'section' => 'header_image',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting('ed_header_bg_overlay',
    array(
        'default' => $coverage_default['ed_header_bg_overlay'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_header_bg_overlay',
    array(
        'label' => esc_html__('Enable BG Overlay', 'coverage'),
        'section' => 'header_image',
        'type' => 'checkbox',
    )
);

// Ticker Section
$wp_customize->add_section( 'header_ticker_section',
    array(
    'title'      => esc_html__( 'Breaking News Ticker', 'coverage' ),
    'priority'   => 10,
    'capability' => 'edit_theme_options',
    'panel'      => 'theme_option_panel',
    )
);

$wp_customize->add_setting('ed_header_ticker_posts',
    array(
        'default' => $coverage_default['ed_header_ticker_posts'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_header_ticker_posts',
    array(
        'label' => esc_html__('Enable Ticker Posts', 'coverage'),
        'section' => 'header_ticker_section',
        'type' => 'checkbox',
    )
);

$wp_customize->add_setting( 'ed_header_ticker_posts_title',
    array(
    'default'           => $coverage_default['ed_header_ticker_posts_title'],
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'sanitize_text_field',
    )
);
$wp_customize->add_control( 'ed_header_ticker_posts_title',
    array(
    'label'       => esc_html__( 'Ticker Section Title', 'coverage' ),
    'section'     => 'header_ticker_section',
    'type'        => 'text',
    )
);


$wp_customize->add_setting( 'coverage_header_ticker_cat',
    array(
    'default'           => '',
    'capability'        => 'edit_theme_options',
    'sanitize_callback' => 'coverage_sanitize_select',
    )
);
$wp_customize->add_control( 'coverage_header_ticker_cat',
    array(
    'label'       => esc_html__( 'Ticker Posts Category', 'coverage' ),
    'section'     => 'header_ticker_section',
    'type'        => 'select',
    'choices'     => $coverage_post_category_list,
    )
);

$wp_customize->add_setting('ed_ticker_slider_autoplay',
    array(
        'default' => $coverage_default['ed_ticker_slider_autoplay'],
        'capability' => 'edit_theme_options',
        'sanitize_callback' => 'coverage_sanitize_checkbox',
    )
);
$wp_customize->add_control('ed_ticker_slider_autoplay',
    array(
        'label' => esc_html__('Enable Ticker Posts Autoplay', 'coverage'),
        'section' => 'header_ticker_section',
        'type' => 'checkbox',
    )
);